@@ -1063,7 +1063,7 @@ mod tests {
 
     use crate::generate_noqa_edits;
     use crate::noqa::{add_noqa_inner, Directive, NoqaMapping, ParsedFileExemption};
-    use crate::rules::pycodestyle::rules::AmbiguousVariableName;
+    use crate::rules::pycodestyle::rules::{AmbiguousVariableName, UselessSemicolon};
     use crate::rules::pyflakes::rules::UnusedVariable;
     use crate::rules::pyupgrade::rules::PrintfStringFormatting;
 
@@ -1380,4 +1380,36 @@ print(
             ))]
         );
     }
+
+    #[test]
+    fn syntax_error() {
+        let path = Path::new("/tmp/foo.txt");
+        let source = "\
+foo;
+bar =
+";
+        let diagnostics = [Diagnostic::new(
+            UselessSemicolon,
+            TextRange::new(4.into(), 5.into()),
+        )];
+        let noqa_line_for = NoqaMapping::default();
+        let comment_ranges = CommentRanges::default();
+        let edits = generate_noqa_edits(
+            path,
+            &diagnostics,
+            &Locator::new(source),
+            &comment_ranges,
+            &[],
+            &noqa_line_for,
+            LineEnding::Lf,
+        );
+        assert_eq!(
+            edits,
+            vec![Some(Edit::replacement(
+                "  # noqa: E703\n".to_string(),
+                4.into(),
+                5.into()
+            ))]
+        );
+    }
 }
