@@ -1,3 +1,5 @@
+#![allow(deprecated)]
+
 use std::fmt::{Display, Formatter};
 use std::hash::{Hash, Hasher};
 use std::ops::Deref;
@@ -500,13 +502,19 @@ impl FromIterator<ExtensionPair> for ExtensionMapping {
     }
 }
 
-#[derive(Clone, Copy, PartialEq, Eq, Serialize, Deserialize, Debug, Hash)]
+#[derive(Clone, Copy, PartialEq, Eq, Serialize, Deserialize, Debug, Hash, Default)]
 #[cfg_attr(feature = "clap", derive(clap::ValueEnum))]
 #[serde(rename_all = "kebab-case")]
 #[cfg_attr(feature = "schemars", derive(schemars::JsonSchema))]
-pub enum SerializationFormat {
+pub enum OutputFormat {
+    // Remove the module level `#![allow(deprecated)` when removing the text variant.
+    // Adding the `#[deprecated]` attribute to text creates clippy warnings about
+    // using a deprecated item in the derived code and there seems to be no way to suppress the clippy error
+    // other than disabling the warning for the entire module and/or moving `OutputFormat` to another module.
+    #[deprecated(note = "Use `concise` or `full` instead")]
     Text,
     Concise,
+    #[default]
     Full,
     Json,
     JsonLines,
@@ -520,7 +528,7 @@ pub enum SerializationFormat {
     Sarif,
 }
 
-impl Display for SerializationFormat {
+impl Display for OutputFormat {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match self {
             Self::Text => write!(f, "text"),
@@ -540,16 +548,6 @@ impl Display for SerializationFormat {
     }
 }
 
-impl SerializationFormat {
-    pub fn default(preview: bool) -> Self {
-        if preview {
-            Self::Full
-        } else {
-            Self::Concise
-        }
-    }
-}
-
 #[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize, Hash)]
 #[serde(try_from = "String")]
 pub struct RequiredVersion(VersionSpecifiers);
